@@ -3,6 +3,7 @@ import datetime as dt
 import ddf
 import pytest
 from django.contrib.auth.models import User
+from django.core.exceptions import FieldDoesNotExist
 from django.db import transaction
 from django.db.utils import NotSupportedError
 
@@ -68,6 +69,7 @@ def test_statement_row_level_logging():
     """
     ddf.G(models.ToLogModel, n=5, field="old_field")
 
+    assert models.ToLogModel.objects.count() == 5
     assert not models.LogEntry.objects.exists()
 
     models.ToLogModel.objects.update(field="new_field")
@@ -76,6 +78,19 @@ def test_statement_row_level_logging():
     # one log entry
     assert models.LogEntry.objects.filter(level="STATEMENT", old_field__isnull=True).count() == 1
 
+    # Verify that we can ignore statement-level triggers. The `ToLogModel` should still update, but
+    # no triggers should fire
+    with pgtrigger.ignore(
+        "tests.ToLogModel:after_update_statement_test",
+        "tests.ToLogModel:update_of_statement_test",
+        "tests.ToLogModel:after_update_row_test",
+    ):
+        models.ToLogModel.objects.update(field="new_field2")
+        assert set(models.ToLogModel.objects.values_list("field", flat=True)) == {"new_field2"}
+        assert (
+            models.LogEntry.objects.filter(level="STATEMENT", old_field__isnull=True).count() == 1
+        )
+
     # The statement-level trigger with references should have made log
     # entries for all of the old values and the new updated values
     assert models.LogEntry.objects.filter(level="STATEMENT", old_field__isnull=False).count() == 5
@@ -660,15 +675,21 @@ def test_changed_condition(condition, expected_sql):
 
 def test_changed_condition_bad_field():
     """Verifies incorrect fields aren't allowed in changed conditions"""
-    with pytest.raises(ValueError, match="not found on model"):
+    with pytest.raises(FieldDoesNotExist, match="has no field"):
         pgtrigger.AnyChange("bad_field").resolve(models.ChangedCondition)
 
-    with pytest.raises(ValueError, match="not found on model"):
+    with pytest.raises(ValueError, match="many-to-many field"):
         pgtrigger.AnyChange("m2m_field").resolve(models.ChangedCondition)
 
-    with pytest.raises(ValueError, match="not found on model"):
+    with pytest.raises(FieldDoesNotExist, match="has no field"):
         pgtrigger.AnyChange(exclude=["bad_field"]).resolve(models.ChangedCondition)
 
+    # Abstract inheritance should work
+    pgtrigger.AnyChange("field").resolve(models.AbstractChild)
+
+    # Referencing foreign key IDs should work
+    pgtrigger.AnyChange("fk_field_id").resolve(models.ChangedCondition)
+
 
 @pytest.mark.django_db(databases=["default", "other"], transaction=True)
 @pytest.mark.order(-2)  # This is a leaky test that modifies the schema. Always run last
